%{?mingw_package_header}

Name:           mingw-curl
Version:        7.74.0
Release:        %mkrel 1
Summary:        MinGW Windows port of curl and libcurl

License:        MIT
Group:          Development/Other
URL:            https://curl.haxx.se/
Source0:        https://curl.haxx.se/download/curl-%{version}.tar.xz

# prevent configure script from discarding -g in CFLAGS (#496778)
Patch0:         0102-curl-7.36.0-debug.patch

BuildArch:      noarch

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-gettext
BuildRequires:  mingw32-win-iconv
BuildRequires:  mingw32-zlib
BuildRequires:  mingw32-libidn2
BuildRequires:  mingw32-libssh2
BuildRequires:  mingw32-openssl

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-gettext
BuildRequires:  mingw64-win-iconv
BuildRequires:  mingw64-zlib
BuildRequires:  mingw64-libidn2
BuildRequires:  mingw64-libssh2
BuildRequires:  mingw64-openssl


%description
cURL is a tool for getting files from HTTP, FTP, FILE, LDAP, LDAPS,
DICT, TELNET and TFTP servers, using any of the supported protocols.
cURL is designed to work without user interaction or any kind of
interactivity. cURL offers many useful capabilities, like proxy
support, user authentication, FTP upload, HTTP post, and file transfer
resume.

This is the MinGW cross-compiled Windows library.


# Win32
%package -n mingw32-curl
Summary:        MinGW Windows port of curl and libcurl
Requires:       pkgconfig

%description -n mingw32-curl
cURL is a tool for getting files from HTTP, FTP, FILE, LDAP, LDAPS,
DICT, TELNET and TFTP servers, using any of the supported protocols.
cURL is designed to work without user interaction or any kind of
interactivity. cURL offers many useful capabilities, like proxy
support, user authentication, FTP upload, HTTP post, and file transfer
resume.

This is the MinGW cross-compiled Windows library.

%package -n mingw32-curl-static
Summary:        Static version of the MinGW Windows Curl library
Requires:       mingw32-curl = %{version}-%{release}

%description -n mingw32-curl-static
Static version of the MinGW Windows Curl library.

# Win64
%package -n mingw64-curl
Summary:        MinGW Windows port of curl and libcurl
Requires:       pkgconfig

%description -n mingw64-curl
cURL is a tool for getting files from HTTP, FTP, FILE, LDAP, LDAPS,
DICT, TELNET and TFTP servers, using any of the supported protocols.
cURL is designed to work without user interaction or any kind of
interactivity. cURL offers many useful capabilities, like proxy
support, user authentication, FTP upload, HTTP post, and file transfer
resume.

This is the MinGW cross-compiled Windows library.

%package -n mingw64-curl-static
Summary:        Static version of the MinGW Windows Curl library
Requires:       mingw64-curl = %{version}-%{release}

%description -n mingw64-curl-static
Static version of the MinGW Windows Curl library.


%{?mingw_debug_package}


%prep
%autosetup -p1 -n curl-%{version}

%build
MINGW32_CONFIGURE_ARGS="--with-ca-bundle=%{mingw32_sysconfdir}/pki/tls/certs/ca-bundle.crt"
MINGW64_CONFIGURE_ARGS="--with-ca-bundle=%{mingw64_sysconfdir}/pki/tls/certs/ca-bundle.crt"
MINGW_CONFIGURE_ARGS="--with-ssl --enable-ipv6 --enable-threaded-resolver --enable-sspi --with-libidn2 --with-libssh2 --without-random"

MINGW_BUILDDIR_SUFFIX=_static %mingw_configure --enable-static --disable-shared
MINGW_BUILDDIR_SUFFIX=_shared %mingw_configure --disable-static --enable-shared

# It's not clear where to set the --with-ca-bundle path.  This is the
# default for CURLOPT_CAINFO.  If this doesn't exist, you'll get an
# error from all https transfers unless the program sets
# CURLOPT_CAINFO to point to the correct ca-bundle.crt file.

# --without-random disables random number collection (eg. from
# /dev/urandom).  There isn't an obvious alternative for Windows:
# Perhaps we can port EGD or use a library such as Yarrow.

# These are the original flags that we'll work towards as
# more of the dependencies get ported to Fedora MinGW.
#
#  --without-ssl --with-nss=%{mingw32_prefix} --enable-ipv6
#  --with-ca-bundle=%{mingw32_sysconfdir}/pki/tls/certs/ca-bundle.crt
#  --with-gssapi=%{mingw32_prefix}/kerberos --with-libidn
#  --enable-ldaps --disable-static --with-libssh2

MINGW_BUILDDIR_SUFFIX=_static %mingw_make %{?_smp_mflags}
MINGW_BUILDDIR_SUFFIX=_shared %mingw_make %{?_smp_mflags}


%install
MINGW_BUILDDIR_SUFFIX=_static %mingw_make DESTDIR=$RPM_BUILD_ROOT/static install
MINGW_BUILDDIR_SUFFIX=_shared %mingw_make DESTDIR=$RPM_BUILD_ROOT install

# The static library from the static build is the only one of interest to us
mv $RPM_BUILD_ROOT/static%{mingw32_libdir}/libcurl.a $RPM_BUILD_ROOT%{mingw32_libdir}/libcurl.a
mv $RPM_BUILD_ROOT/static%{mingw64_libdir}/libcurl.a $RPM_BUILD_ROOT%{mingw64_libdir}/libcurl.a
rm -rf $RPM_BUILD_ROOT/static

# Remove .la files
find $RPM_BUILD_ROOT -name "*.la" -delete

# Remove the man pages which duplicate documentation in the
# native Fedora package.
rm -r $RPM_BUILD_ROOT%{mingw32_mandir}/man{1,3}
rm -r $RPM_BUILD_ROOT%{mingw64_mandir}/man{1,3}

# Remove redundant autoconf files
rm -rf $RPM_BUILD_ROOT%{mingw32_datadir}/aclocal
rm -rf $RPM_BUILD_ROOT%{mingw64_datadir}/aclocal


# Win32
%files -n mingw32-curl
%doc COPYING
%{mingw32_bindir}/curl.exe
%{mingw32_bindir}/curl-config
%{mingw32_bindir}/libcurl-4.dll
%{mingw32_libdir}/libcurl.dll.a
%{mingw32_libdir}/pkgconfig/libcurl.pc
%{mingw32_includedir}/curl/

%files -n mingw32-curl-static
%{mingw32_libdir}/libcurl.a

# Win64
%files -n mingw64-curl
%doc COPYING
%{mingw64_bindir}/curl.exe
%{mingw64_bindir}/curl-config
%{mingw64_bindir}/libcurl-4.dll
%{mingw64_libdir}/libcurl.dll.a
%{mingw64_libdir}/pkgconfig/libcurl.pc
%{mingw64_includedir}/curl/

%files -n mingw64-curl-static
%{mingw64_libdir}/libcurl.a




%changelog
* Tue Dec 15 2020 daviddavid <daviddavid> 7.74.0-1.mga8
+ Revision: 1657707
- new version: 7.74.0

* Thu Nov 19 2020 daviddavid <daviddavid> 7.73.0-1.mga8
+ Revision: 1647529
- new version: 7.73.0

* Sat Sep 26 2020 tv <tv> 7.71.1-2.mga8
+ Revision: 1630203
- rebuild for new mingw stack

* Mon Aug 10 2020 daviddavid <daviddavid> 7.71.1-1.mga8
+ Revision: 1613010
- Update to 7.71.1, which fixes the following vulnerabilities
  * CVE-2020-8169 - curl: Partial password leak over DNS on HTTP redirect
  * CVE-2020-8177 - curl: overwrite local file with -J

* Wed Mar 11 2020 daviddavid <daviddavid> 7.69.1-1.mga8
+ Revision: 1555520
- new version: 7.69.1

* Thu Mar 05 2020 daviddavid <daviddavid> 7.69.0-1.mga8
+ Revision: 1553911
- new version: 7.69.0

* Wed Feb 19 2020 umeabot <umeabot> 7.68.0-2.mga8
+ Revision: 1542958
- Mageia 8 Mass Rebuild

* Wed Jan 08 2020 daviddavid <daviddavid> 7.68.0-1.mga8
+ Revision: 1477285
- new version: 7.68.0

* Fri Nov 15 2019 daviddavid <daviddavid> 7.67.0-1.mga8
+ Revision: 1460422
- new version: 7.67.0

* Fri Sep 06 2019 daviddavid <daviddavid> 7.65.3-1.mga8
+ Revision: 1437720
- new version: 7.65.3

* Wed Apr 17 2019 daviddavid <daviddavid> 7.64.1-1.mga7
+ Revision: 1391981
- new version: 7.64.1

* Fri Feb 08 2019 daviddavid <daviddavid> 7.64.0-1.mga7
+ Revision: 1364200
- new version: 7.64.0

* Thu Sep 20 2018 umeabot <umeabot> 7.61.1-2.mga7
+ Revision: 1279527
- Mageia 7 Mass Rebuild

* Wed Sep 05 2018 daviddavid <daviddavid> 7.61.1-1.mga7
+ Revision: 1257300
- new version: 7.61.1

* Sun Jul 22 2018 daviddavid <daviddavid> 7.61.0-1.mga7
+ Revision: 1244771
- new version: 7.61.0
- switch to libidn2
- fix IDN support and debug symbols, enable SSPI support, ship user binary

* Tue Jul 10 2018 daviddavid <daviddavid> 7.57.0-1.mga7
+ Revision: 1242952
- new version: 7.57.0

* Wed May 11 2016 tv <tv> 7.47.0-1.mga6
+ Revision: 1012437
- new release

* Tue Feb 02 2016 umeabot <umeabot> 7.32.0-4.mga6
+ Revision: 932796
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 7.32.0-3.mga5
+ Revision: 749902
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 7.32.0-2.mga5
+ Revision: 682418
- Mageia 5 Mass Rebuild

* Sun Sep 22 2013 neoclust <neoclust> 7.32.0-1.mga4
+ Revision: 483492
- imported package mingw-curl


* Sat Sep  7 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.32.0-1
- Update to 7.32.0

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.31.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 13 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.31.0-1
- Update to 7.31.0

* Sun Mar 24 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.29.0-1
- Update to 7.29.0

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.28.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 21 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.28.1-1
- Update to 7.28.1
- Removed all patches as they're not needed for the mingw target

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.25.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sun Apr 08 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.25.0-1
- Update to 7.25.0
- Added win64 support (contributed by Marc-Andre Lureau)
- Dropped upstreamed patches
- Dropped unneeded RPM tags

* Fri Mar 09 2012 Kalev Lember <kalevlember@gmail.com> - 7.20.1-7
- Remove .la files

* Tue Mar 06 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.20.1-6
- Renamed the source package to mingw-curl (RHBZ #800375)
- Use mingw macros without leading underscore
- Dropped unneeded RPM tags

* Mon Feb 27 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.20.1-5
- Rebuild against the mingw-w64 toolchain
- Let curl use its own errno/WSA error codes
- The function ftruncate64 doesn't need to be reimplemented by curl
  as the mingw-w64 crt already contains an implementation for it

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.20.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Jul 06 2011 Kalev Lember <kalevlember@gmail.com> - 7.20.1-3
- Rebuilt against win-iconv

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.20.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu May 13 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.20.1-1
- Update to 7.20.1
- Merged the patches of the native .spec file (7.20.1-5)
- Dropped the curl.exe
- Use the Win32 threads API instead of mingw32-pthreads
- Dropped BR: pkgconfig

* Fri Dec 11 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.19.7-1
- Update to 7.19.8
- Merged the patches of the native .spec file (7.19.7-8)
- Use %%global instead of %%define
- Automatically generate debuginfo subpackage

* Sat May  9 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.19.4-2
- Merged the patches of the native .spec file (7.19.4-10)

* Fri Apr  3 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 7.19.4-1
- Update to version 7.19.4
- Fixed %%defattr line
- Added -static subpackage. Applications which want to use this
  static library need to add -DCURL_STATICLIB to the CFLAGS
- Merged the patches of the native .spec file (7.19.4-5)

* Fri Feb 20 2009 Richard W.M. Jones <rjones@redhat.com> - 7.18.2-6
- Rebuild for mingw32-gcc 4.4

* Fri Feb  6 2009 Richard W.M. Jones <rjones@redhat.com> - 7.18.2-5
- Include license.

* Fri Feb  6 2009 Richard W.M. Jones <rjones@redhat.com> - 7.18.2-4
- Rebuild against new OpenSSH (because of soname bump).

* Fri Jan 30 2009 Richard W.M. Jones <rjones@redhat.com> - 7.18.2-3
- Requires pkgconfig.

* Thu Nov 13 2008 Richard W.M. Jones <rjones@redhat.com> - 7.18.2-2
- Requires mingw32-filesystem >= 35.

* Thu Nov 13 2008 Richard W.M. Jones <rjones@redhat.com> - 7.18.2-1
- Initial RPM release.
